nider\.colors package
=====================

Submodules
----------

nider\.colors\.colormap module
------------------------------

.. automodule:: nider.colors.colormap
    :members:
    :undoc-members:
    :show-inheritance:

nider\.colors\.utils module
---------------------------

.. automodule:: nider.colors.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nider.colors
    :members:
    :undoc-members:
    :show-inheritance:
